bayespy.nodes.GaussianGammaARD.initialize_from_parameters
=========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaARD.initialize_from_parameters